cv.views — Django-Vitae 0.0.1 documentation

# `cv.views`

Reference for `cv.views` generated from docstrings.

class `cv.views.` `CVListMixin`

  Class of helper functions to gather data for CV sections.

  `sum_items`(dict)

    Sum items across dictionaries.

  `get_cv_list`(model)

    Gather data for CV section into dictionaries.

  `get_cv_primary_positions`()

    Return dictionary of CV data with current positions.

class `cv.views.` `CVView`(**kwargs)

  An HTML representation of a CV.

  `get_context_data`(**kwargs)

    Return dictionary of different types of CV entries.

class `cv.views.` `CVListView`(**kwargs)

  Creates view of all instances for a particular section.

  `dispatch`(request, *args, **kwargs)

    Set class parameters based on URL and dispatch.

  `get_queryset`()

    Return the list of items for this view.

    The return value must be an iterable and may be an instance of QuerySet in which case QuerySet specific behavior will be enabled.

  `get_template_names`()

    Returns the name template to use to display a list of model instances.

    Currently returns `cv/lists/<model_name>_list.html`.

    Might add a generic template for vitae models in the future.

class `cv.views.` `CVDetailView`(**kwargs)

  Creates view of a single instance of a CV item.

  `get_template_names`()

    Returns the name template to use to display a list of model instances.

    Currently returns `cv/lists/<model_name>_detail.html`.

    Might add a generic template for vitae models in the future.

`cv.views.` `citation_view`(request, model_name, slug, format)

  Returns view to allow citation to be downloaded to citation management software.